## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(scToppR)
suppressMessages({
  library(airway)
  library(DESeq2)
})
data("airway")

se <- airway
rownames(se) <- rowData(se)$gene_name

dds <- DESeqDataSet(se, design = ~ cell + dex)

smallestGroupSize <- 3
keep <- rowSums(counts(dds) >= 10) >= smallestGroupSize
dds <- dds[keep,]

dds <- DESeq(dds)
res <- results(dds)

#add the gene names as a column in the results
res$gene <- rownames(res)

#add cluster column - here, with this bulk RNAseq data, we will only have 1 cluster
res$cluster <- "cluster0"

## ----toppFun------------------------------------------------------------------
toppData <- toppFun(res,
                    gene_col = "gene",
                    cluster_col = "cluster",
                    p_val_col = "padj",
                    logFC_col = "log2FoldChange")
head(toppData)

## ----plot1, fig.dim=c(8,8)----------------------------------------------------
toppPlot(toppData, 
         category = "GeneOntologyMolecularFunction", 
         clusters = "cluster0")

## ----plot_list, fig.dim=c(8,8)------------------------------------------------
plot_list <- toppPlot(toppData, 
         category = "GeneOntologyMolecularFunction", 
         clusters = NULL)
plot_list[1]

## ----plot_save, eval=FALSE----------------------------------------------------
# plot_list <- toppPlot(toppData,
#          category = "GeneOntologyMolecularFunction",
#          clusters = NULL,
#          save = TRUE,
#          save_dir = "./GO_results",
#          file_prefix = "GO_molecular_function")

## ----plot_balloon, fig.dim=c(8,5)---------------------------------------------
toppBalloon(toppData,
            categories = "GeneOntologyBiologicalProcess")

## ----plot_balloon2, fig.dim=c(8,5)--------------------------------------------
toppBalloon(toppData,
            categories = "Pathway")

## ----plot_balloon3, fig.dim=c(8,5)--------------------------------------------
toppBalloon(toppData,
            categories = "Pubmed")

## ----save, eval=FALSE---------------------------------------------------------
# 
# toppSave(toppData,
#          filename = "airway_toppData",
#          save_dir = "./toppData_results"
#          split = TRUE,
#          format = "xlsx")
# 

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

