## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(scToppR)
library(dplyr)
data("ifnb.de")
head(ifnb.de)

## ----filtering----------------------------------------------------------------
ifnb.de.filtered <- ifnb.de |>
  dplyr::filter(p_val_adj < 0.05, abs(avg_log2FC) > 0.3)

## ----toppFun------------------------------------------------------------------
toppData <- toppFun(ifnb.de.filtered,
                    gene_col = "gene",
                    cluster_col = "celltype",
                    p_val_col = "p_val_adj",
                    logFC_col = "avg_log2FC")
head(toppData)

## ----plot1, fig.dim=c(8,8)----------------------------------------------------
toppPlot(toppData, 
         category = "GeneOntologyMolecularFunction", 
         clusters = "CD8 T")

## ----plot_list, fig.dim=c(8,8)------------------------------------------------
plot_list <- toppPlot(toppData, 
         category = "GeneOntologyMolecularFunction", 
         clusters = NULL)
plot_list[1]

## ----plot_save, eval=FALSE----------------------------------------------------
# plot_list <- toppPlot(toppData,
#          category = "GeneOntologyMolecularFunction",
#          clusters = NULL,
#          save = TRUE,
#          save_dir = "./GO_results",
#          file_prefix = "GO_molecular_function")

## ----plot_balloon, fig.dim=c(8,5)---------------------------------------------
toppBalloon(toppData,
            categories = "GeneOntologyBiologicalProcess")

## ----plot_balloon2, fig.dim=c(8,5)--------------------------------------------
toppBalloon(toppData,
            categories = "Pathway")

## ----plot_balloon3, fig.dim=c(8,5)--------------------------------------------
toppBalloon(toppData,
            categories = "Pubmed")

## ----save, eval=FALSE---------------------------------------------------------
# 
# toppSave(toppData,
#          filename = "IFNB_toppData",
#          save_dir = "./toppData_results"
#          split = TRUE,
#          format = "xlsx")
# 

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

